Class: Google::Apis::ManagedidentitiesV1beta1::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1beta1::DenyMaintenancePeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb
Overview
DenyMaintenancePeriod definition. Maintenance is forbidden within the deny period. The start_date must be less than the end_date.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ManagedidentitiesV1beta1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::ManagedidentitiesV1beta1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::ManagedidentitiesV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
409 410 411 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ManagedidentitiesV1beta1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
388 389 390 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 388 def end_date @end_date end |
#start_date ⇒ Google::Apis::ManagedidentitiesV1beta1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
400 401 402 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 400 def start_date @start_date end |
#time ⇒ Google::Apis::ManagedidentitiesV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
407 408 409 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 407 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
414 415 416 417 418 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 414 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |