Class: Google::Apis::ManagedidentitiesV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb

Overview

SloMetadata contains resources required for proper SLO classification of the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata

Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloMetadata.



1349
1350
1351
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::ManagedidentitiesV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1NodeSloMetadata>

Optional. List of nodes. Some producers need to use per-node metadata to calculate SLO. This field allows such producers to publish per-node SLO meta data, which will be consumed by SSA Eligibility Exporter and published in the form of per node metric to Monarch. Corresponds to the JSON property nodes



1335
1336
1337
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1335

def nodes
  @nodes
end

#per_sli_eligibilityGoogle::Apis::ManagedidentitiesV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1PerSliSloEligibility

PerSliSloEligibility is a mapping from an SLI name to eligibility. Corresponds to the JSON property perSliEligibility



1340
1341
1342
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1340

def per_sli_eligibility
  @per_sli_eligibility
end

#tierString

Name of the SLO tier the Instance belongs to. This name will be expected to match the tiers specified in the service SLO configuration. Field is mandatory and must not be empty. Corresponds to the JSON property tier

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1347

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1354
1355
1356
1357
1358
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1354

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
  @per_sli_eligibility = args[:per_sli_eligibility] if args.key?(:per_sli_eligibility)
  @tier = args[:tier] if args.key?(:tier)
end