Class: Google::Apis::ManagedidentitiesV1beta1::ListPeeringsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb

Overview

ListPeeringsResponse is the response message for ListPeerings method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPeeringsResponse

Returns a new instance of ListPeeringsResponse.



1574
1575
1576
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1562

def next_page_token
  @next_page_token
end

#peeringsArray<Google::Apis::ManagedidentitiesV1beta1::Peering>

A list of Managed Identities Service Peerings in the project. Corresponds to the JSON property peerings



1567
1568
1569
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1567

def peerings
  @peerings
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1572
1573
1574
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1572

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1579
1580
1581
1582
1583
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1579

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @peerings = args[:peerings] if args.key?(:peerings)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end