Class: Google::Apis::ManagedidentitiesV1beta1::ListSqlIntegrationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb

Overview

ListSqlIntegrationsResponse is the response message for ListSqlIntegrations method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSqlIntegrationsResponse

Returns a new instance of ListSqlIntegrationsResponse.



1607
1608
1609
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1595

def next_page_token
  @next_page_token
end

#sql_integrationsArray<Google::Apis::ManagedidentitiesV1beta1::SqlIntegration>

A list of SqlIntegrations of a domain. Corresponds to the JSON property sqlIntegrations



1600
1601
1602
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1600

def sql_integrations
  @sql_integrations
end

#unreachableArray<String>

A list of locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1605
1606
1607
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1605

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1612
1613
1614
1615
1616
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1612

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @sql_integrations = args[:sql_integrations] if args.key?(:sql_integrations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end