Class: Google::Apis::ManagedidentitiesV1beta1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1beta1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ManagedidentitiesV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
2184 2185 2186 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 2184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
2170 2171 2172 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 2170 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
2175 2176 2177 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 2175 def duration @duration end |
#start_time ⇒ Google::Apis::ManagedidentitiesV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2182 2183 2184 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 2182 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2189 2190 2191 2192 2193 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 2189 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |