Class: Google::Apis::ManagedidentitiesV1beta1::Peering
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1beta1::Peering
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1beta1/classes.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb,
lib/google/apis/managedidentities_v1beta1/representations.rb
Overview
Represents a Managed Microsoft Identities Peering.
Instance Attribute Summary collapse
-
#authorized_network ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#domain_resource ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Peering
constructor
A new instance of Peering.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Peering
Returns a new instance of Peering.
1979 1980 1981 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_network ⇒ String
Required. The full names of the Google Compute Engine networks to which the instance is connected. Caller
needs to make sure that CIDR subnets do not overlap between networks, else
peering creation will fail.
Corresponds to the JSON property authorizedNetwork
1937 1938 1939 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1937 def @authorized_network end |
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
1942 1943 1944 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1942 def create_time @create_time end |
#domain_resource ⇒ String
Required. Full domain resource path for the Managed AD Domain involved in
peering. The resource path should be in the form: projects/project_id/
locations/global/domains/domain_name`
Corresponds to the JSON propertydomainResource`
1949 1950 1951 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1949 def domain_resource @domain_resource end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
1954 1955 1956 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1954 def labels @labels end |
#name ⇒ String
Output only. Unique name of the peering in this scope including projects and
location using the form: projects/project_id/locations/global/peerings/
peering_id`.
Corresponds to the JSON propertyname`
1961 1962 1963 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1961 def name @name end |
#state ⇒ String
Output only. The current state of this Peering.
Corresponds to the JSON property state
1966 1967 1968 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1966 def state @state end |
#status_message ⇒ String
Output only. Additional information about the current status of this peering,
if available.
Corresponds to the JSON property statusMessage
1972 1973 1974 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1972 def @status_message end |
#update_time ⇒ String
Output only. Last update time.
Corresponds to the JSON property updateTime
1977 1978 1979 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1977 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/google/apis/managedidentities_v1beta1/classes.rb', line 1984 def update!(**args) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @create_time = args[:create_time] if args.key?(:create_time) @domain_resource = args[:domain_resource] if args.key?(:domain_resource) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @update_time = args[:update_time] if args.key?(:update_time) end |